==> haskell-atomic-primops-0.8.5-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-atomic-primops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 atomic-primops
version:              0.8.5
visibility:           public
id:                   atomic-primops-0.8.5-DWxtaOEoPFe53KJyJQyWQz
key:                  atomic-primops-0.8.5-DWxtaOEoPFe53KJyJQyWQz
license:              BSD-3-Clause
maintainer:           rrnewton@gmail.com
author:               Ryan Newton
homepage:             https://github.com/rrnewton/haskell-lockfree/wiki
synopsis:             A safe approach to CAS and other atomic ops in Haskell.
description:
     After GHC 7.4 a new `casMutVar#` primop became available, but it'\''s
     difficult to use safely, because pointer equality is a highly
     unstable property in Haskell.  This library provides a safer method
     based on the concept of "Tickets".
    .
     Also, this library uses the "foreign primop" capability of GHC to
     add access to other variants that may be of
     interest, specifically, compare and swap inside an array.
    .
     Note that as of GHC 7.8, the relevant primops have been included in GHC itself.
     This library is engineered to work pre- and post-GHC-7.8, while exposing the
     same interface.

category:             Data
abi:                  b4e5d699a0284fd5c8f043352979d982
exposed:              True
exposed-modules:
    Data.Atomics Data.Atomics.Counter Data.Atomics.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/atomic-primops-0.8.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/atomic-primops-0.8.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-atomic-primops
hs-libraries:         HSatomic-primops-0.8.5-DWxtaOEoPFe53KJyJQyWQz
depends:
    base-4.16.4.0 ghc-prim-0.8.0
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx

haddock-interfaces:
    /usr/share/doc/haskell-atomic-primops/html/atomic-primops.haddock

haddock-html:         /usr/share/doc/haskell-atomic-primops/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-atomic-primops-0.8.8-5.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-atomic-primops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 atomic-primops
version:              0.8.8
visibility:           public
id:                   atomic-primops-0.8.8-58h9mGG8PWs8MBqu97uFJO
key:                  atomic-primops-0.8.8-58h9mGG8PWs8MBqu97uFJO
license:              BSD-3-Clause
maintainer:           rrnewton@gmail.com
author:               Ryan Newton
homepage:             https://github.com/rrnewton/haskell-lockfree/wiki
synopsis:             A safe approach to CAS and other atomic ops in Haskell.
description:
     After GHC 7.4 a new `casMutVar#` primop became available, but it'\''s
     difficult to use safely, because pointer equality is a highly
     unstable property in Haskell.  This library provides a safer method
     based on the concept of "Tickets".
    .
     Also, this library uses the "foreign primop" capability of GHC to
     add access to other variants that may be of
     interest, specifically, compare and swap inside an array.
    .
     Note that as of GHC 7.8, the relevant primops have been included in GHC itself.
     This library is engineered to work pre- and post-GHC-7.8, while exposing the
     same interface.

category:             Data
abi:                  90df705fb947bef6d5ad3d6ed5a38c5d
exposed:              True
exposed-modules:
    Data.Atomics Data.Atomics.Counter Data.Atomics.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/atomic-primops-0.8.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/atomic-primops-0.8.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/atomic-primops-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-atomic-primops
hs-libraries:         HSatomic-primops-0.8.8-58h9mGG8PWs8MBqu97uFJO
depends:
    base-4.17.2.1 ghc-prim-0.9.1
    primitive-0.8.0.0-RoAiLvCruBL00EsvIFp5f

haddock-interfaces:
    /usr/share/doc/haskell-atomic-primops/html/atomic-primops.haddock

haddock-html:         /usr/share/doc/haskell-atomic-primops/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
